===================
Project Information
===================

Authors and Contributors
========================

.. include:: _contributors.rst


Getting in Touch
================

Please use the `GitHub issues page <https://github.com/ASPP/pelita/issues>`_ for questions and discussion.

License
=======

Pelita is licensed under the terms of the `Simplified (two-clause) BSD License
<https://www.opensource.org/licenses/BSD-2-Clause>`_.
A copy of the license is included with the source, in the file ``COPYING``.

Acknowledgements
================

The game is inspired by the `“Pac-Man Projects”
<http://inst.eecs.berkeley.edu/~cs188/pacman/project_overview.html>`_  developed
by John DeNero and Dan Klein at Berkeley University for their artificial intelligence
introductory course [DeNeroKlein]_.

This software was developed for the “Advanced Scientific Programming in Python”
summer school, as a teaching aid for the group project.

* `Camerino, Italy, 2019 <https://python.g-node.org/wiki/start>`_
* `Camerino, Italy, 2018 <https://python.g-node.org/python-summerschool-2018/>`_
* `Nikiti, Greece, 2017 <https://python.g-node.org/python-summerschool-2017/>`_
* `Reading, UK, 2016 <https://python.g-node.org/python-summerschool-2016/>`_
* `Munich, Germany, 2015 <https://python.g-node.org/python-summerschool-2015/>`_
* `Split, Croatia, 2014 <https://python.g-node.org/python-summerschool-2014/>`_
* `Zürich, Switzerland, <https://python.g-node.org/python-summerschool-2013/>`_
* `Kiel, Germany, <https://python.g-node.org/python-summerschool-2012/>`_
* `St Andrews, Scotland, 2011 <https://python.g-node.org/python-summerschool-2011>`_
* `Trento, Italy, 2010 <https://python.g-node.org/python-autumnschool-2010/>`_
* `Warsaw, Poland, 2010 <https://python.g-node.org/python-winterschool-2010>`_
* `Berlin, Germany, 2009 <https://python.g-node.org/python-summerschool-2009>`_

Initial funding was kindly provided by `The German Neuroinformatics Node
<http://www.g-node.org/>`_.



References
==========

.. [DeNeroKlein] John DeNero and Dan Klein. Teaching Introductory Artificial
   Intelligence with Pac-Man. In *proceedings of the Symposium on Educational
   Advances in Artificial Intelligence (EAAI)*, 2010.
   `pdf <http://www.denero.org/content/pubs/eaai10_denero_pacman.pdf>`_
